/*
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * "The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations under
 * the License.
 *
 * The Original Code is ICEfaces 1.5 open source software code, released
 * November 5, 2006. The Initial Developer of the Original Code is ICEsoft
 * Technologies Canada, Corp. Portions created by ICEsoft are Copyright (C)
 * 2004-2006 ICEsoft Technologies Canada, Corp. All Rights Reserved.
 *
 * Contributor(s): _____________________.
 *
 * Alternatively, the contents of this file may be used under the terms of
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"
 * License), in which case the provisions of the LGPL License are
 * applicable instead of those above. If you wish to allow use of your
 * version of this file only under the terms of the LGPL License and not to
 * allow others to use your version of this file under the MPL, indicate
 * your decision by deleting the provisions above and replace them with
 * the notice and other provisions required by the LGPL License. If you do
 * not delete the provisions above, a recipient may use your version of
 * this file under either the MPL or the LGPL License."
 *
 */
package com.icesoft.faces.component.jsfcl.data;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.Collections;
import java.util.Comparator;
import java.util.List;
import java.util.logging.Level;
import java.util.logging.Logger;

import javax.faces.event.ValueChangeEvent;
import javax.faces.model.SelectItem;

import com.icesoft.faces.component.selectinputtext.SelectInputText;


public class AutoComplete implements Serializable {

	private static Logger log = Logger
			.getLogger("com.icesoft.faces.component.selectinputtext");

	// List of possible matches for autocomplete component.
	private List matchesList = new ArrayList();
	/**
	 * Holds value of property dataList.
	 */
	private List dataList = new ArrayList();

	public AutoComplete() {

	}

	/**
	 * The the list of possible matches for the given SelectInputText value
	 * 
	 * @return list of possible matches.
	 */
	public List getMatchesList() {
		return matchesList;
	}

	/**
	 * Called when a user has modifed the SelectInputText value. This method
	 * call causes the match list to be updated.
	 * 
	 * @param event
	 */
	public void updateList(ValueChangeEvent event) {
		// get a new list of matches.
		setMatches(event);
		// Get the auto complete component from the event
		if (event.getComponent() instanceof SelectInputText) {
			SelectInputText autoComplete = (SelectInputText) event
					.getComponent();
			// if there is a selected item get the value from the match list.
			if (autoComplete.getSelectedItem() != null) {
				try {
					
					Object selectedObject = autoComplete.getSelectedItem().getValue();
					log.log(Level.FINEST, " selected object"+ selectedObject);					
				} catch (Exception e) {
					log.log(Level.FINEST, "Cannot update list "
							+ e.getMessage());
				}
			}
		}
	}

	/**
	 * Utility method for building the match list given the current value of the
	 * SelectInputText component.
	 * 
	 * @param event
	 */
	private void setMatches(ValueChangeEvent event) {
		Object searchWord = event.getNewValue();
		int maxMatches = ((SelectInputText) event.getComponent()).getRows();
		List matchList = new ArrayList(maxMatches);
		getDataList();
		try {
			int insert = Collections.binarySearch(dataList, searchWord,
					LABEL_COMPARATOR);
			// less than zero if wer have a partial match
			if (insert < 0) {
				insert = Math.abs(insert) - 1;
			}
			for (int i = 0; i < maxMatches; i++) {
				// quit the match list creation if the index is larger than
				// max entries in the dictionary of we have added maxMatches.
				if ((insert + i) >= dataList.size() || i >= maxMatches) {
					break;
				}
				matchList.add(dataList.get(insert + i));
			}
		} catch (Throwable e) {
			log.log(Level.FINEST, "Error finding autocomplete matches"
					+ e.getMessage());
		}
		// assign new matchList
		if (this.matchesList != null) {
			this.matchesList.clear();
			this.matchesList = null;
		}
		this.matchesList = matchList;
	}



	// Comparator utility for sorting SelectItem labels in autocomplete
	// component.
	public static final Comparator LABEL_COMPARATOR = new Comparator() {
		String s1;

		String s2;

		// compare method for entries.
		public int compare(Object o1, Object o2) {
			s1 = ((SelectItem) o1).getLabel();
			if (o2 instanceof SelectItem) {
				s2 = ((SelectItem) o2).getLabel();
			} else {
				s2 = o2.toString();
			}
			// compare ignoring case, give the user a more automated feel when
			// typing
			return s1.compareToIgnoreCase(s2);
		}
	};

	public List getDataList() {
		if(dataList.isEmpty()){
			dataList.add(new SelectItem("mac"));
			dataList.add(new SelectItem("linux"));
			dataList.add(new SelectItem("windows"));
		}
		return dataList;
	}

	public void setDataList(List dataList) {
		this.dataList = dataList;
	}
}
