/*
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * "The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations under
 * the License.
 *
 * The Original Code is ICEfaces 1.5 open source software code, released
 * November 5, 2006. The Initial Developer of the Original Code is ICEsoft
 * Technologies Canada, Corp. Portions created by ICEsoft are Copyright (C)
 * 2004-2006 ICEsoft Technologies Canada, Corp. All Rights Reserved.
 *
 * Contributor(s): _____________________.
 *
 * Alternatively, the contents of this file may be used under the terms of
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"
 * License), in which case the provisions of the LGPL License are
 * applicable instead of those above. If you wish to allow use of your
 * version of this file only under the terms of the LGPL License and not to
 * allow others to use your version of this file under the MPL, indicate
 * your decision by deleting the provisions above and replace them with
 * the notice and other provisions required by the LGPL License. If you do
 * not delete the provisions above, a recipient may use your version of
 * this file under either the MPL or the LGPL License."
 *
 */
package com.icesoft.faces.component.jsfcl.data;

import java.util.TreeMap;
import java.util.logging.Level;
import java.util.logging.Logger;

import javax.faces.model.DataModel;
import javax.faces.model.DataModelEvent;
import javax.faces.model.DataModelListener;
import javax.sql.rowset.CachedRowSet;

import com.sun.data.provider.FieldKey;
import com.sun.data.provider.RowKey;
import com.sun.data.provider.SortCriteria;
import com.sun.data.provider.TableDataProvider;
import com.sun.data.provider.TableDataSorter;
import com.sun.data.provider.impl.BasicTableDataSorter;
import com.sun.data.provider.impl.CachedRowSetDataProvider;
import com.sun.data.provider.impl.FieldKeySortCriteria;

public class CachedRowSetSortableDataModel extends DataModel {

	private static Logger log = Logger.getLogger("com.icesoft.faces.component.jsfcl.data.CachedRowSetSortableDataModel");

	private boolean ascending;

	private int index = -1;

	private TreeMap rows[] = null;

	private String sort;

	private CachedRowSet cachedRowSet;

	private SortCriteria[] sortCriteria;

	public CachedRowSetSortableDataModel() {
		this(null);
	}

	public CachedRowSetSortableDataModel(CachedRowSet cachedRowSet) {
		super();
		setWrappedData(cachedRowSet);
		log.log(Level.FINEST, "cachedRow Model init");
	}

	public int getRowCount() {

		log.log(Level.FINEST," cachedRow Model rowCount=");
		if (cachedRowSet == null) {
			return -1;
		} else {
			return rows.length;
		}
	}

	public Object getWrappedData() {
		log.log(Level.FINEST,"getWrapperData");
		return cachedRowSet;
	}

	public boolean isRowAvailable() {

		if (cachedRowSet == null || rows == null) {
			return false;
		} else if ((index >= 0) && (index < rows.length)) {
			return true;
		} else {
			return false;
		}
	}

	public void setWrappedData(Object data) {

		if (data == null) {
			cachedRowSet = null;
			rows = null;
			setRowIndex(-1);
		} else {
			if (data instanceof CachedRowSet) {
				cachedRowSet = (CachedRowSet) data;                                
				rows = getSortedDataCache();
			} else {
				log.log(Level.FINEST,"wrong data = " + data.getClass().getName());
				throw new IllegalArgumentException();
			}
		}
	}

	public boolean isAscending() {
		log.log(Level.FINEST," ascending = " + ascending);
		return ascending;
	}

	public void setAscending(boolean ascending) {
		log.log(Level.FINEST,"set ascending = " + ascending);
		this.ascending = ascending;
	}

	public String getSort() {

		if (sort != null) {
			log.log(Level.FINEST,"call getSort criteria=" + sort);
		}
		return sort;
	}

	public void setSort(String sort) {
		this.sort = sort;

		// TODO
		if (sort != null) {
			FieldKey fieldKey = new FieldKey(getSort());
			SortCriteria oneCriteria = new FieldKeySortCriteria(fieldKey,
					isAscending());
			sortCriteria = new SortCriteria[] { oneCriteria };
			getSortedDataCache();
		}
		log.log(Level.FINEST,"new criteria =" + sort);

	}

	public void setSortCriteria(SortCriteria[] sortCriteria) {
		this.sortCriteria = sortCriteria;
		log.log(Level.FINEST,"set sort criteria");
	}

	public SortCriteria[] getSortCriteria() {

		if (sortCriteria == null) {

			FieldKey fieldKey = new FieldKey(getSort());
			SortCriteria oneCriteria = new FieldKeySortCriteria(fieldKey,
					isAscending());
			sortCriteria = new SortCriteria[] { oneCriteria };
		}
		log.log(Level.FINEST,"get sort criteria");
		return sortCriteria;
	}

	private RowKey[] getSortedRowKeys(TableDataProvider tableDataProvider,
			RowKey[] rowKeys) {

		TableDataSorter sorter = new BasicTableDataSorter();
		sorter.setSortCriteria(getSortCriteria());
		RowKey[] sortedRowKeys = sorter.sort(tableDataProvider, rowKeys);
		return sortedRowKeys;
	}

	public Object getRowData() {

		if (cachedRowSet == null) {
			return null;
		} else if (!isRowAvailable()) {
			throw new IllegalArgumentException();
		} else {
			return rows[index];
		}
	}

	private TreeMap[] getSortedDataCache() {

		// TODO: synchronzied RowSet
		TableDataProvider tableDataProvider = new CachedRowSetDataProvider(
				cachedRowSet);

		if (tableDataProvider.getRowCount() != -1) {

			FieldKey[] fieldKeys = tableDataProvider.getFieldKeys();

			for (int j = 0; j < fieldKeys.length; j++) {
				log.log(Level.FINEST,"field key=" + fieldKeys[j].getDisplayName()
						+ "field id=" + fieldKeys[j].getFieldId());
			}

			if (getSort() == null) {
				setSort(fieldKeys[0].getFieldId());
				ascending = true;
			}
			RowKey[] rowKeys = tableDataProvider.getRowKeys(
					Integer.MAX_VALUE, null);
			rowKeys = getSortedRowKeys(tableDataProvider, rowKeys);
			rows = new TreeMap[rowKeys.length];

			for (int j = 0; j < rowKeys.length; j++) {

				TreeMap row = new TreeMap(String.CASE_INSENSITIVE_ORDER);
				for (int i = 0; i < fieldKeys.length; i++) {
					row.put(fieldKeys[i].getFieldId(), tableDataProvider
							.getValue(fieldKeys[i], rowKeys[j]));
				}
				rows[j] = row;
			}
		} else {
			log.log(Level.FINEST," RowSet has no data" + tableDataProvider.getRowCount());
		}
		log.log(Level.FINEST,"dataCached rows=" + rows.length);
		return rows;
	}

	public int getRowIndex() {
		return index;

	}

	public void setRowIndex(int rowIndex) {

		if (rowIndex < -1) {
			throw new IllegalArgumentException();
		}
		int old = index;
		index = rowIndex;
		if (cachedRowSet == null) {
			return;
		}

		DataModelListener[] listeners = getDataModelListeners();
		if ((old != index) && (listeners != null)) {
			Object rowData = null;
			if (isRowAvailable()) {
				rowData = getRowData();
			}
			DataModelEvent event = new DataModelEvent(this, index, rowData);
			int n = listeners.length;
			for (int i = 0; i < n; i++) {
				if (null != listeners[i]) {
					listeners[i].rowSelected(event);
				}
			}
		}
	}
}
