/*
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * "The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations under
 * the License.
 *
 * The Original Code is ICEfaces 1.5 open source software code, released
 * November 5, 2006. The Initial Developer of the Original Code is ICEsoft
 * Technologies Canada, Corp. Portions created by ICEsoft are Copyright (C)
 * 2004-2006 ICEsoft Technologies Canada, Corp. All Rights Reserved.
 *
 * Contributor(s): _____________________.
 *
 * Alternatively, the contents of this file may be used under the terms of
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"
 * License), in which case the provisions of the LGPL License are
 * applicable instead of those above. If you wish to allow use of your
 * version of this file only under the terms of the LGPL License and not to
 * allow others to use your version of this file under the MPL, indicate
 * your decision by deleting the provisions above and replace them with
 * the notice and other provisions required by the LGPL License. If you do
 * not delete the provisions above, a recipient may use your version of
 * this file under either the MPL or the LGPL License."
 *
 */
package com.icesoft.faces.component.jsfcl.data;

import com.sun.data.provider.FieldKey;
import com.sun.data.provider.RowKey;
import com.sun.data.provider.TableDataProvider;
import com.sun.data.provider.impl.CachedRowSetDataProvider;
import com.sun.rave.faces.data.CachedRowSetDataModel;
import java.beans.Beans;
import java.util.TreeMap;
import java.util.logging.Level;
import java.util.logging.Logger;
import javax.faces.model.DataModel;
import javax.sql.rowset.CachedRowSet;

/**
 *
 * @author fye
 */
public class CachedRowSetWrapperDataModel extends DataModel {

    private static Logger log = Logger.getLogger("com.icesoft.faces.component.jsfcl.data.CachedRowSetWrapperDataModel");
    private CachedRowSet cachedRowSet;
    private TreeMap rows[] = null;
    private int index = -1;

    /**
     * <p>Construct a new {@link CachedRowSetDataModel} with no specified
     * wrapped data.</p>
     */
    public CachedRowSetWrapperDataModel() {

        this(null);
    }

    /**
     * <p>Construct a new {@link CachedRowSetDataModel} wrapping the specified
     * <code>CachedRowSet</code>.</p>
     *
     * @param cachedRowSet <code>CachedRowSet</code> to be wrapped (if any)
     */
    public CachedRowSetWrapperDataModel(CachedRowSet cachedRowSet) {

        super();
        setWrappedData(cachedRowSet);
    }

    @Override
    public boolean isRowAvailable() {
        if (cachedRowSet == null) {
            return false;
        } else if ((index >= 0) && (index < rows.length)) {
            return true;
        } else {
            return false;
        }
    }

    @Override
    public int getRowCount() {
        if (cachedRowSet == null) {
            return -1;
        } else {
            return rows.length;
        }
    }

    @Override
    public Object getRowData() {
        if (cachedRowSet == null) {
            return null;
        } else if (!isRowAvailable()) {
            if(!Beans.isDesignTime()){
                throw new IllegalArgumentException();   
            }else{
                return null;
            }
        } else {
            return rows[index];
        }
    }

    @Override
    public int getRowIndex() {
        return index;
    }

    @Override
    public void setRowIndex(int rowIndex) {
        if (rowIndex < -1) {
            throw new IllegalArgumentException();
        }
        index = rowIndex;
        if (cachedRowSet == null) {
            return;
        }
    }

    @Override
    public Object getWrappedData() {
        return rows;
    }

    @Override
    public void setWrappedData(Object data) {
        if (data == null) {
            cachedRowSet = null;
            rows = null;
            setRowIndex(-1);
        } else {
            if (data instanceof CachedRowSet) {
                cachedRowSet = (CachedRowSet) data;
                rows = initDataCache();
            } else {
                log.log(Level.FINEST, "wrong data = " + data.getClass().getName());
                throw new IllegalArgumentException();
            }
        }
    }

    private TreeMap[] initDataCache() {

        // TODO: synchronzied RowSet
        TableDataProvider tableDataProvider = new CachedRowSetDataProvider(
                cachedRowSet);
        if (tableDataProvider.getRowCount() != -1) {
            FieldKey[] fieldKeys = tableDataProvider.getFieldKeys();
            for (int j = 0; j < fieldKeys.length; j++) {
                String val = fieldKeys[j].getFieldId();
                int loc = val.lastIndexOf('.');
                if (loc >= 0 && loc + 1 < val.length()) {
                    val = val.substring(loc + 1);
                }
                fieldKeys[j].setDisplayName(val);
                log.log(Level.FINEST, "field key=" + fieldKeys[j].getDisplayName() + "field id=" + fieldKeys[j].getFieldId());
            }

            RowKey[] rowKeys = tableDataProvider.getRowKeys(Integer.MAX_VALUE, null);
            rows = new TreeMap[rowKeys.length];
            for (int j = 0; j < rowKeys.length; j++) {

                TreeMap row = new TreeMap();
                for (int i = 0; i < fieldKeys.length; i++) {
                    row.put(fieldKeys[i].getDisplayName(), tableDataProvider.getValue(fieldKeys[i], rowKeys[j]));
                }
                rows[j] = row;
            }
        } else {
            log.log(Level.FINEST, " RowSet has no data" + tableDataProvider.getRowCount());
        }
        log.log(Level.FINEST, "dataCached rows=" + rows.length);
        return rows;
    }
}
