/*
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * "The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations under
 * the License.
 *
 * The Original Code is ICEfaces 1.5 open source software code, released
 * November 5, 2006. The Initial Developer of the Original Code is ICEsoft
 * Technologies Canada, Corp. Portions created by ICEsoft are Copyright (C)
 * 2004-2006 ICEsoft Technologies Canada, Corp. All Rights Reserved.
 *
 * Contributor(s): _____________________.
 *
 * Alternatively, the contents of this file may be used under the terms of
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"
 * License), in which case the provisions of the LGPL License are
 * applicable instead of those above. If you wish to allow use of your
 * version of this file only under the terms of the LGPL License and not to
 * allow others to use your version of this file under the MPL, indicate
 * your decision by deleting the provisions above and replace them with
 * the notice and other provisions required by the LGPL License. If you do
 * not delete the provisions above, a recipient may use your version of
 * this file under either the MPL or the LGPL License."
 *
 */
package com.icesoft.faces.component.jsfcl.data;

import javax.swing.tree.DefaultMutableTreeNode;
import javax.swing.tree.DefaultTreeModel;

import com.icesoft.faces.component.tree.Tree;

/**
 * <p>
 * The TreeBean class is the backing bean for the Tree Component showcase
 * demonstration. It is used to store and display the selected tree node
 * </p>
 * 
 * @since 0.3.0
 */
public class DefaultTree {

	// root node control todo:
	//private boolean hideRootNode;

	// selected node name
	private String selectedNode = "";

	// Tree default model, used as a value for the tree component
	private DefaultTreeModel model;

	// Binding to tree component
	private Tree treeComponent;

	// label count
	private int labelCount = 0;
	
	/**
	 * Construction the default tree structure by combining tree nodes.
	 */
	public DefaultTree() {

		DefaultMutableTreeNode rootTreeNode = new DefaultMutableTreeNode();
		NodeUserObject rootObject = new NodeUserObject(rootTreeNode, this);
		rootTreeNode.setUserObject(rootObject);

		model = new DefaultTreeModel(rootTreeNode);

		for (int i = 0; i < 2; i++) {
			DefaultMutableTreeNode branchNode = new DefaultMutableTreeNode();
			NodeUserObject branchObject = new NodeUserObject(branchNode, this);
			branchNode.setUserObject(branchObject);
			rootTreeNode.add(branchNode);

			for (int k = 0; k < 1; k++) {
				DefaultMutableTreeNode subbranchNode = new DefaultMutableTreeNode();
				NodeUserObject subBranchObject = new NodeUserObject(
						subbranchNode, this);
				subbranchNode.setUserObject(subBranchObject);
				branchNode.add(subbranchNode);
				
				for (int l = 0; l < 1; l++) {
					DefaultMutableTreeNode subbranchNodeTwo = new DefaultMutableTreeNode();
					NodeUserObject subBranchObjectTwo = new NodeUserObject(
							subbranchNodeTwo, this);
					subbranchNodeTwo.setUserObject(subBranchObjectTwo);
					subbranchNode.add(subbranchNodeTwo);
											
					for (int m = 0; m < 3; m++) {
						DefaultMutableTreeNode subbranchNodeThree = new DefaultMutableTreeNode();
						NodeUserObject subBranchObjectThree = new NodeUserObject(
								subbranchNodeThree, this);
						subbranchNodeThree.setUserObject(subBranchObjectThree);
						subbranchNodeTwo.add(subbranchNodeThree);
																
					}
				}
				
			}
		}
	}

	/**
	 * Gets the tree's default model.
	 * 
	 * @return tree model.
	 */
	public DefaultTreeModel getModel() {
		return model;
	}

	/**
	 * Sets the tree's default model.
	 * 
	 * @param model
	 *            new default tree model
	 */
	public void setModel(DefaultTreeModel model) {
		this.model = model;
	}

	/**
	 * Gets the tree node component which can be bound to the JSF component.
	 * 
	 * @return tree binging object
	 */
	public Tree getTreeComponent() {
		return treeComponent;
	}

	/**
	 * Sets the tree component.
	 * 
	 * @param treeComponent
	 *            tree component.
	 */
	public void setTreeComponent(Tree treeComponent) {
		this.treeComponent = treeComponent;
	}

	/**
	 * Gets the selected node display text.
	 * 
	 * @return selected node display text.
	 */
	public String getSelectedNode() {
		return selectedNode;
	}

	/**
	 * Sets the selected node. This changes a local instance viarable used for
	 * display, it does not directly change the tree node state.
	 * 
	 * @param selectedNode
	 *            selected node text.
	 */
	public void setSelectedNode(String selectedNode) {
		this.selectedNode = selectedNode;
	}

	/**
	 * Increment the label count and return it.
	 * 
	 * @return the new label count
	 */
	public int getIncreasedLabelCount() {
		return ++labelCount;
	}
}
