/*
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * "The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See the
 * License for the specific language governing rights and limitations under
 * the License.
 *
 * The Original Code is ICEfaces 1.5 open source software code, released
 * November 5, 2006. The Initial Developer of the Original Code is ICEsoft
 * Technologies Canada, Corp. Portions created by ICEsoft are Copyright (C)
 * 2004-2006 ICEsoft Technologies Canada, Corp. All Rights Reserved.
 *
 * Contributor(s): _____________________.
 *
 * Alternatively, the contents of this file may be used under the terms of
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"
 * License), in which case the provisions of the LGPL License are
 * applicable instead of those above. If you wish to allow use of your
 * version of this file only under the terms of the LGPL License and not to
 * allow others to use your version of this file under the MPL, indicate
 * your decision by deleting the provisions above and replace them with
 * the notice and other provisions required by the LGPL License. If you do
 * not delete the provisions above, a recipient may use your version of
 * this file under either the MPL or the LGPL License."
 *
 */
package com.icesoft.faces.component.jsfcl.data;

import java.io.Serializable;

import javax.faces.component.UIComponent;
import javax.faces.context.FacesContext;
import javax.faces.event.ActionEvent;

/**
 * <p>The MenuBarBean class determines which menu item 
 * fired the ActionEvent and stores the modified id information
 * in a String. MenuBarBean also controls the orientation
 * of the Menu Bar.</p>
 */
public class MenuBarBean implements Serializable{

	// records which menu item fired the event
	private String actionFired;
	
	// orientation of the menubar ("horizontal" or "vertical")
	private String orientation = "vertical";
	
	public MenuBarBean(){
		
	}
	
	/**
	 * Get the modified ID of the fired action.
	 * 
	 * @return the modified ID
	 */
	public String getActionFired() {
		return actionFired;
	}
	
	/**
	 * Identify the ID of the element that fired the event
	 * and return it in a form suitable for display.
	 * 
	 * @param e the event that fired the listener
	 */
	public void primaryListener (ActionEvent e){
		actionFired = (String) ((UIComponent)e.getSource()).getClientId(FacesContext.getCurrentInstance());
		// chop off the meaningless numbers, etc. from the id tag
        int menuIndex = actionFired.indexOf("menu:");
        actionFired = actionFired.substring(menuIndex, actionFired.length());
	}

	/**
	 * Get the orientation of the menu ("horizontal" or "vertical")
	 * 
	 * @return the orientation of the menu
	 */
	public String getOrientation() {
		return orientation;
	}

	/**
	 * Set the orientation of the menu ("horizontal" or "vertical").
	 * 
	 * @param orientation the new orientation of the menu
	 */
	public void setOrientation(String orientation) {
		this.orientation = orientation;
	}
}